=======
Credits
=======

Development Lead
----------------

* Basil Shubin - bashu <basil.shubin@gmail.com>
* Antonio Ercole De Luca <eracle@posteo.eu>

Contributors
------------

None yet. Why not be the first?
